@@ -19,7 +19,9 @@ import (
 func migrateExportCommand(cmd *cobra.Command, args []string) {
 	ensureWorkingCopyClean(os.Stdin, os.Stderr)
 
-	l := tasklog.NewLogger(os.Stderr)
+	l := tasklog.NewLogger(os.Stderr,
+		tasklog.ForceProgress(cfg.ForceProgress()),
+	)
 	defer l.Close()
 
 	db, err := getObjectDatabase()
@@ -134,7 +136,7 @@ func migrateExportCommand(cmd *cobra.Command, args []string) {
 			}
 
 			if _, err := os.Stat(downloadPath); os.IsNotExist(err) {
-				q.Add(p.Name, downloadPath, p.Oid, p.Size)
+				q.Add(p.Name, downloadPath, p.Oid, p.Size, false)
 			}
 		})
 		gs.ScanRefs(opts.Include, opts.Exclude, nil)
