@@ -9,10 +9,11 @@ import (
 var (
 	GitCommit   string
 	VersionDesc string
+	Vendor      string
 )
 
 const (
-	Version = "2.7.1"
+	Version = "2.8.0"
 )
 
 func init() {
@@ -20,8 +21,12 @@ func init() {
 	if len(GitCommit) > 0 {
 		gitCommit = "; git " + GitCommit
 	}
-	VersionDesc = fmt.Sprintf("git-lfs/%s (GitHub; %s %s; go %s%s)",
+	if len(Vendor) == 0 {
+		Vendor = "GitHub"
+	}
+	VersionDesc = fmt.Sprintf("git-lfs/%s (%s; %s %s; go %s%s)",
 		Version,
+		Vendor,
 		runtime.GOOS,
 		runtime.GOARCH,
 		strings.Replace(runtime.Version(), "go", "", 1),
