@@ -34,7 +34,7 @@ import (
 	"sync"
 	"time"
 
-	"github.com/ThomsonReutersEikon/go-ntlm/ntlm"
+	"github.com/git-lfs/go-ntlm/ntlm"
 )
 
 var (
@@ -215,10 +215,22 @@ func lfsHandler(w http.ResponseWriter, r *http.Request, id string) {
 		return
 	}
 
+	// Check that we're sending valid data.
+	if !strings.Contains(r.Header.Get("Accept"), "application/vnd.git-lfs+json") {
+		w.WriteHeader(406)
+		return
+	}
+
 	debug(id, "git lfs %s %s repo: %s", r.Method, r.URL, repo)
 	w.Header().Set("Content-Type", "application/vnd.git-lfs+json")
 	switch r.Method {
 	case "POST":
+		// Reject invalid data.
+		if !strings.Contains(r.Header.Get("Content-Type"), "application/vnd.git-lfs+json") {
+			w.WriteHeader(400)
+			return
+		}
+
 		if strings.HasSuffix(r.URL.String(), "batch") {
 			lfsBatchHandler(w, r, id, repo)
 		} else {
@@ -749,6 +761,37 @@ func storageHandler(w http.ResponseWriter, r *http.Request) {
 					byteLimit = 8
 					batchResumeFailFallbackStorageAttempts++
 				}
+			} else if string(by) == "status-batch-retry" {
+				if rangeHdr := r.Header.Get("Range"); rangeHdr != "" {
+					regex := regexp.MustCompile(`bytes=(\d+)\-(.*)`)
+					match := regex.FindStringSubmatch(rangeHdr)
+					// We have a Range header with two
+					// non-empty values.
+					if match != nil && len(match) > 2 && len(match[2]) != 0 {
+						first, _ := strconv.ParseInt(match[1], 10, 32)
+						second, _ := strconv.ParseInt(match[2], 10, 32)
+						// The second part of the range
+						// is smaller than the first
+						// part (or the latter part of
+						// the range is non-integral).
+						// This is invalid; reject it.
+						if second < first {
+							w.WriteHeader(400)
+							return
+						}
+						// The range is valid; we'll
+						// take the branch below.
+					}
+					// We got a valid range header, so
+					// provide a 206 Partial Content. We
+					// ignore the upper bound if one was
+					// provided.
+					if match != nil && len(match) > 1 {
+						statusCode = 206
+						resumeAt, _ = strconv.ParseInt(match[1], 10, 32)
+						w.Header().Set("Content-Range", fmt.Sprintf("bytes %d-%d/%d", resumeAt, len(by), resumeAt-int64(len(by))))
+					}
+				}
 			}
 			w.WriteHeader(statusCode)
 			if byteLimit > 0 {
